@@ -1,4 +1,5 @@
-import statsmodels
+import statsmodels.tsa.api as sm
+import statsmodels.tsa.ar_model as ar_model
 
 
 def train(data, used_model='autoreg', p=5, d=1, q=0, cov_type='nonrobust', method='cmle', ic='aic', trend='nc', solver='lbfgs',
@@ -20,27 +21,26 @@ def train(data, used_model='autoreg', p=5, d=1, q=0, cov_type='nonrobust', metho
     """
 
     if used_model == 'ar':
-        model = statsmodels.tsa.ar_model.AR(data)
+        model = sm.AR(data)
 
     elif used_model == 'arma':
         order = (p, q)
-        model = statsmodels.tsa.arima_model.ARMA(data, order=order)
+        model = sm.ARMA(data, order=order)
 
     elif used_model == 'arima':
         order = (p, d, q)
-        model = statsmodels.tsa.arima_model.ARIMA(data, order=order)
+        model = sm.ARIMA(data, order=order)
 
     elif used_model == 'sarimax':
-        from statsmodels.tsa.statespace.sarimax import SARIMAX
         order = (p, d, q)
-        model = SARIMAX(data, order=order, seasonal_order=seasonal)
+        model = sm.SARIMAX(data, order=order, seasonal_order=seasonal)
 
     if used_model in ('ar', 'arma', 'arima', 'sarimax'):
         fitted_model = model.fit(method=method, ic=ic, trend=trend, solver=solver, disp=0)
 
     elif used_model == 'autoreg':
-        auto = statsmodels.tsa.ar_model.ar_select_order(data, maxlag=40)
-        model = statsmodels.tsa.ar_model.AutoReg(data, lags=auto.ar_lags, trend=auto.trend, seasonal=auto.seasonal, period=auto.period)
+        auto = ar_model.ar_select_order(data, maxlag=40)
+        model = ar_model.AutoReg(data, lags=auto.ar_lags, trend=auto.trend, seasonal=auto.seasonal, period=auto.period)
         fitted_model = model.fit(cov_type=cov_type)
 
     fitted_model.my_name = used_model
